# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ExecutionProtocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ExecutionProtocol.proto',
  package='com.spirent.service.execution.protocol',
  serialized_pb=_b('\n\x17\x45xecutionProtocol.proto\x12&com.spirent.service.execution.protocol\"\xfc\x13\n\x10\x45xecutionMessage\x12K\n\x04type\x18\x01 \x02(\x0e\x32=.com.spirent.service.execution.protocol.ExecutionMessage.Type\x12L\n\rcancelMessage\x18\x02 \x01(\x0b\x32\x35.com.spirent.service.execution.protocol.CancelMessage\x12R\n\x10heartbeatMessage\x18\x03 \x01(\x0b\x32\x38.com.spirent.service.execution.protocol.HeartbeatMessage\x12H\n\x0binitMessage\x18\x04 \x01(\x0b\x32\x33.com.spirent.service.execution.protocol.InitMessage\x12\x44\n\tinvokeAck\x18\x05 \x01(\x0b\x32\x31.com.spirent.service.execution.protocol.InvokeAck\x12L\n\rinvokeMessage\x18\x06 \x01(\x0b\x32\x35.com.spirent.service.execution.protocol.InvokeMessage\x12N\n\x0einvokeResponse\x18\x07 \x01(\x0b\x32\x36.com.spirent.service.execution.protocol.InvokeResponse\x12L\n\rreportMessage\x18\x08 \x01(\x0b\x32\x35.com.spirent.service.execution.protocol.ReportMessage\x12H\n\x0bstepMessage\x18\t \x01(\x0b\x32\x33.com.spirent.service.execution.protocol.StepMessage\x12R\n\x10terminateMessage\x18\n \x01(\x0b\x32\x38.com.spirent.service.execution.protocol.TerminateMessage\x12J\n\x0ctokenMessage\x18\x0b \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.TokenMessage\x12\\\n\x15\x65xecutionIssueMessage\x18\x0c \x01(\x0b\x32=.com.spirent.service.execution.protocol.ExecutionIssueMessage\x12M\n\x11newSessionMessage\x18\r \x01(\x0b\x32\x32.com.spirent.service.execution.protocol.NewSession\x12V\n\x12newSessionResponse\x18\x0e \x01(\x0b\x32:.com.spirent.service.execution.protocol.NewSessionResponse\x12Y\n\x17sendTerminalDataMessage\x18\x0f \x01(\x0b\x32\x38.com.spirent.service.execution.protocol.SendTerminalData\x12\x62\n\x18sendTerminalDataResponse\x18\x10 \x01(\x0b\x32@.com.spirent.service.execution.protocol.SendTerminalDataResponse\x12S\n\x14sessionActionMessage\x18\x11 \x01(\x0b\x32\x35.com.spirent.service.execution.protocol.SessionAction\x12\\\n\x15sessionActionResponse\x18\x12 \x01(\x0b\x32=.com.spirent.service.execution.protocol.SessionActionResponse\x12J\n\x0clistProjects\x18\x13 \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.ListProjects\x12Z\n\x14listProjectsResponse\x18\x14 \x01(\x0b\x32<.com.spirent.service.execution.protocol.ListProjectsResponse\x12J\n\x0cqueryProject\x18\x15 \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.QueryProject\x12Z\n\x14queryProjectResponse\x18\x16 \x01(\x0b\x32<.com.spirent.service.execution.protocol.QueryProjectResponse\x12J\n\x0cquerySession\x18\x17 \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.QuerySession\x12Z\n\x14querySessionResponse\x18\x18 \x01(\x0b\x32<.com.spirent.service.execution.protocol.QuerySessionResponse\"\xa3\x04\n\x04Type\x12\x12\n\x0e\x43\x41NCEL_MESSAGE\x10\x01\x12\x15\n\x11HEARTBEAT_MESSAGE\x10\x02\x12\x10\n\x0cINIT_MESSAGE\x10\x03\x12\x0e\n\nINVOKE_ACK\x10\x04\x12\x12\n\x0eINVOKE_MESSAGE\x10\x05\x12\x13\n\x0fINVOKE_RESPONSE\x10\x06\x12\x12\n\x0eREPORT_MESSAGE\x10\x07\x12\x10\n\x0cSTEP_MESSAGE\x10\x08\x12\x15\n\x11TERMINATE_MESSAGE\x10\t\x12\x11\n\rTOKEN_MESSAGE\x10\n\x12\x1b\n\x17\x45XECUTION_ISSUE_MESSAGE\x10\x0b\x12\x17\n\x13NEW_SESSION_MESSAGE\x10\x0c\x12\x18\n\x14NEW_SESSION_RESPONSE\x10\r\x12\x1e\n\x1aSEND_TERMINAL_DATA_MESSAGE\x10\x0e\x12\x1f\n\x1bSEND_TERMINAL_DATA_RESPONSE\x10\x0f\x12\x1a\n\x16SESSION_ACTION_MESSAGE\x10\x10\x12\x1b\n\x17SESSION_ACTION_RESPONSE\x10\x11\x12\x11\n\rLIST_PROJECTS\x10\x12\x12\x1a\n\x16LIST_PROJECTS_RESPONSE\x10\x13\x12\x11\n\rQUERY_PROJECT\x10\x14\x12\x1a\n\x16QUERY_PROJECT_RESPONSE\x10\x15\x12\x11\n\rQUERY_SESSION\x10\x16\x12\x1a\n\x16QUERY_SESSION_RESPONSE\x10\x17\"\"\n\rCancelMessage\x12\x11\n\tsessionId\x18\x01 \x02(\t\"\xe8\x03\n\x15\x45xecutionIssueMessage\x12\x0f\n\x07\x66ileUri\x18\x01 \x02(\t\x12\x12\n\nissueIndex\x18\x02 \x02(\r\x12\x10\n\x08location\x18\x03 \x02(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x12\n\noriginator\x18\x05 \x01(\t\x12\x15\n\rprocedureName\x18\x06 \x01(\t\x12\x10\n\x08reportId\x18\x07 \x02(\t\x12\x11\n\tsessionId\x18\x08 \x02(\t\x12\x65\n\x08severity\x18\t \x01(\x0e\x32\x46.com.spirent.service.execution.protocol.ExecutionIssueMessage.Severity:\x0bINFORMATION\x12\x0e\n\x06stepId\x18\n \x02(\t\x12\x16\n\x0etestCaseStepId\x18\x0b \x02(\t\x12\x0c\n\x04line\x18\x0c \x01(\x04\x12\x10\n\x08startCol\x18\r \x01(\x04\x12\x0e\n\x06\x65ndCol\x18\x0e \x01(\x04\x12\x11\n\tlineCount\x18\x0f \x01(\x04\x12\x13\n\x0bsequenceNum\x18\x10 \x01(\x04\x12\x11\n\tissueTime\x18\x11 \x01(\x04\"=\n\x08Severity\x12\t\n\x05\x45RROR\x10\x00\x12\x0f\n\x0bINFORMATION\x10\x01\x12\x08\n\x04PASS\x10\x02\x12\x0b\n\x07WARNING\x10\x03\"b\n\x10HeartbeatMessage\x12\x17\n\x0bmemoryUsage\x18\x01 \x01(\x01:\x02-1\x12\x1a\n\x0eprocessCpuLoad\x18\x02 \x01(\x01:\x02-1\x12\x19\n\rsystemCpuLoad\x18\x03 \x01(\x01:\x02-1\"1\n\tInvokeAck\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x11\n\tstartTime\x18\x02 \x01(\x04\"g\n\x05Param\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x41\n\nparameters\x18\x03 \x03(\x0b\x32-.com.spirent.service.execution.protocol.Param\"\x9e\x06\n\rInvokeMessage\x12\x43\n\x05token\x18\x01 \x02(\x0b\x32\x34.com.spirent.service.execution.protocol.TokenMessage\x12L\n\x06header\x18\x02 \x03(\x0b\x32<.com.spirent.service.execution.protocol.InvokeMessage.Header\x12\x10\n\x08reportId\x18\x03 \x02(\t\x12\x15\n\rdependencyUri\x18\x04 \x03(\t\x12\x14\n\x0cparamFileUri\x18\x05 \x03(\t\x12\x41\n\nparameters\x18\x06 \x03(\x0b\x32-.com.spirent.service.execution.protocol.Param\x12V\n\x0breservation\x18\x07 \x01(\x0b\x32\x41.com.spirent.service.execution.protocol.InvokeMessage.Reservation\x12\x12\n\ntestbedUri\x18\x08 \x01(\t\x12\x13\n\x0btestCaseUri\x18\t \x02(\t\x12l\n\x0b\x64\x65tailLevel\x18\n \x01(\x0e\x32\x41.com.spirent.service.execution.protocol.InvokeMessage.DetailLevel:\x14\x41LL_ISSUES_ALL_STEPS\x1a%\n\x06Header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x1a\x44\n\x0bReservation\x12\x15\n\rreservationId\x18\x01 \x02(\t\x12\x1e\n\x16reservationVelocityUrl\x18\x02 \x02(\t\"\x9b\x01\n\x0b\x44\x65tailLevel\x12\x0f\n\x0bREPORT_ONLY\x10\x00\x12\x15\n\x11\x45RROR_ISSUES_ONLY\x10\x01\x12\x1b\n\x17\x45RROR_ISSUES_WITH_STEPS\x10\x02\x12\x1a\n\x16\x41LL_ISSUES_ERROR_STEPS\x10\x03\x12\x18\n\x14\x41LL_ISSUES_ALL_STEPS\x10\x04\x12\x11\n\rLAST_RESPONSE\x10\x05\"\xde\x02\n\x0bInitMessage\x12\x0f\n\x07\x61gentId\x18\x01 \x02(\t\x12\x11\n\tagentName\x18\x02 \x02(\t\x12\x17\n\x0fprotocolVersion\x18\x03 \x02(\t\x12R\n\ncapability\x18\x04 \x03(\x0b\x32>.com.spirent.service.execution.protocol.InitMessage.Capability\x12\x11\n\tsessionId\x18\x05 \x01(\t\x12T\n\x0brestriction\x18\x06 \x03(\x0b\x32?.com.spirent.service.execution.protocol.InitMessage.Restriction\x1a)\n\nCapability\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x1a*\n\x0bRestriction\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"\x88\x02\n\x0eInvokeResponse\x12J\n\x0creportResult\x18\x01 \x02(\x0e\x32\x34.com.spirent.service.execution.protocol.ReportResult\x12\x11\n\tstartTime\x18\x02 \x02(\x04\x12\x0f\n\x07\x65ndTime\x18\x03 \x02(\x04\x12\x11\n\tsessionId\x18\x04 \x02(\t\x12K\n\x05\x65rror\x18\x05 \x01(\x0b\x32<.com.spirent.service.execution.protocol.InvokeResponse.Error\x1a&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x02(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x10TerminateMessage\x12\r\n\x05\x63\x61use\x18\x01 \x01(\t\"\x1d\n\x0cTokenMessage\x12\r\n\x05token\x18\x01 \x02(\t\"\xbd\x02\n\rReportMessage\x12\x10\n\x08reportId\x18\x01 \x02(\t\x12\x11\n\tstartTime\x18\x02 \x01(\x04\x12\x0f\n\x07\x65ndTime\x18\x03 \x01(\x04\x12\x17\n\x0fparentStepIndex\x18\x04 \x01(\t\x12\x16\n\x0eparentReportId\x18\x05 \x01(\t\x12\x10\n\x08testPath\x18\x06 \x01(\t\x12\x0e\n\x06testId\x18\x07 \x01(\t\x12\x44\n\x06result\x18\x08 \x01(\x0e\x32\x34.com.spirent.service.execution.protocol.ReportResult\x12\x1a\n\x12percentageComplete\x18\t \x01(\x01\x12\x41\n\nparameters\x18\n \x03(\x0b\x32-.com.spirent.service.execution.protocol.Param\"\xa1\x0f\n\x0bStepMessage\x12\x10\n\x08reportId\x18\x01 \x02(\t\x12\x0e\n\x06stepId\x18\x02 \x02(\t\x12\x14\n\x0cparentStepId\x18\x03 \x01(\t\x12\x16\n\x0etestCaseStepId\x18\x04 \x02(\t\x12\x10\n\x08threadId\x18\x05 \x01(\x05\x12\x11\n\tsessionId\x18\x06 \x01(\t\x12\x13\n\x0bsessionType\x18\x07 \x01(\t\x12\x11\n\tprocedure\x18\x08 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\t \x01(\t\x12\x0f\n\x07\x63ontext\x18\n \x01(\t\x12\x0e\n\x06target\x18\x0b \x01(\t\x12\x0f\n\x07\x63ommand\x18\x0c \x01(\t\x12\x13\n\x0bstartOffset\x18\r \x01(\x01\x12\x10\n\x08\x64uration\x18\x0e \x01(\x01\x12\x17\n\x08\x65mulated\x18\x0f \x01(\x08:\x05\x66\x61lse\x12R\n\nstepResult\x18\x10 \x01(\x0e\x32>.com.spirent.service.execution.protocol.StepMessage.StepResult\x12X\n\x07\x64\x65tails\x18\x11 \x01(\x0b\x32G.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails\x12\x12\n\nproperties\x18\x12 \x01(\t\x12\x13\n\x0bsequenceNum\x18\x13 \x01(\x04\x1az\n\x06\x41\x63tion\x12\x0e\n\x06\x61\x63tion\x18\x01 \x02(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12K\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32:.com.spirent.service.execution.protocol.StepMessage.Action\x1a\xd1\t\n\x13StepResponseDetails\x12\x1b\n\x0cisAutoMapped\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12R\n\x0epostProcessing\x18\x03 \x03(\x0b\x32:.com.spirent.service.execution.protocol.StepMessage.Action\x12k\n\ranalysisRules\x18\x04 \x03(\x0b\x32T.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule\x12n\n\x0estructuredData\x18\x05 \x03(\x0b\x32V.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData\x12^\n\x07\x61liases\x18\x06 \x03(\x0b\x32M.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias\x1a\xd9\x01\n\x05\x41lias\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0bqueryFormat\x18\x02 \x01(\t\x12i\n\targuments\x18\x03 \x03(\x0b\x32V.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument\x1a\x42\n\x08\x41rgument\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0bvaluesQuery\x18\x02 \x01(\t\x12\x13\n\x0binterpretAs\x18\x03 \x01(\t\x1a\xa8\x01\n\x0c\x41nalysisRule\x12\x11\n\textractor\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08whenTrue\x18\x03 \x01(\t\x12\x11\n\twhenFalse\x18\x04 \x01(\t\x12K\n\x07\x61\x63tions\x18\x05 \x03(\x0b\x32:.com.spirent.service.execution.protocol.StepMessage.Action\x1a\xf6\x02\n\x0eStructuredData\x12\x0b\n\x03map\x18\x08 \x02(\t\x12\x16\n\x0eresponseMapUri\x18\t \x01(\t\x12j\n\x05items\x18\n \x03(\x0b\x32[.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item\x1a\xd2\x01\n\x04Item\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\x05\x12\x11\n\tlineCount\x18\x03 \x01(\x05\x12\x10\n\x08startCol\x18\x04 \x01(\x05\x12\x0e\n\x06\x65ndCol\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\t\x12j\n\x05items\x18\x07 \x03(\x0b\x32[.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item\"L\n\nStepResult\x12\x0b\n\x07\x41\x42ORTED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07SKIPPED\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\"\xf2\r\n\x1b\x43lientSessionControlMessage\x12V\n\x04type\x18\x01 \x02(\x0e\x32H.com.spirent.service.execution.protocol.ClientSessionControlMessage.Type\x12\x41\n\x0binitMessage\x18\x02 \x01(\x0b\x32,.com.spirent.service.execution.protocol.Init\x12J\n\x0cinitResponse\x18\x03 \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.InitResponse\x12M\n\x11newSessionMessage\x18\x04 \x01(\x0b\x32\x32.com.spirent.service.execution.protocol.NewSession\x12V\n\x12newSessionResponse\x18\x05 \x01(\x0b\x32:.com.spirent.service.execution.protocol.NewSessionResponse\x12Y\n\x17sendTerminalDataMessage\x18\x06 \x01(\x0b\x32\x38.com.spirent.service.execution.protocol.SendTerminalData\x12\x62\n\x18sendTerminalDataResponse\x18\x07 \x01(\x0b\x32@.com.spirent.service.execution.protocol.SendTerminalDataResponse\x12S\n\x14sessionActionMessage\x18\x08 \x01(\x0b\x32\x35.com.spirent.service.execution.protocol.SessionAction\x12\\\n\x15sessionActionResponse\x18\t \x01(\x0b\x32=.com.spirent.service.execution.protocol.SessionActionResponse\x12[\n\x18sessionTerminatedMessage\x18\n \x01(\x0b\x32\x39.com.spirent.service.execution.protocol.SessionTerminated\x12J\n\x0clistProjects\x18\x0b \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.ListProjects\x12Z\n\x14listProjectsResponse\x18\x0c \x01(\x0b\x32<.com.spirent.service.execution.protocol.ListProjectsResponse\x12J\n\x0cqueryProject\x18\r \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.QueryProject\x12Z\n\x14queryProjectResponse\x18\x0e \x01(\x0b\x32<.com.spirent.service.execution.protocol.QueryProjectResponse\x12J\n\x0cquerySession\x18\x0f \x01(\x0b\x32\x34.com.spirent.service.execution.protocol.QuerySession\x12Z\n\x14querySessionResponse\x18\x10 \x01(\x0b\x32<.com.spirent.service.execution.protocol.QuerySessionResponse\"\xfd\x02\n\x04Type\x12\x10\n\x0cINIT_MESSAGE\x10\x01\x12\x11\n\rINIT_RESPONSE\x10\x02\x12\x17\n\x13NEW_SESSION_MESSAGE\x10\x03\x12\x18\n\x14NEW_SESSION_RESPONSE\x10\x04\x12\x1e\n\x1aSEND_TERMINAL_DATA_MESSAGE\x10\x05\x12\x1f\n\x1bSEND_TERMINAL_DATA_RESPONSE\x10\x06\x12\x1a\n\x16SESSION_ACTION_MESSAGE\x10\x07\x12\x1b\n\x17SESSION_ACTION_RESPONSE\x10\x08\x12\x16\n\x12SESSION_TERMINATED\x10\t\x12\x11\n\rLIST_PROJECTS\x10\n\x12\x1a\n\x16LIST_PROJECTS_RESPONSE\x10\x0b\x12\x11\n\rQUERY_PROJECT\x10\x0c\x12\x1a\n\x16QUERY_PROJECT_RESPONSE\x10\r\x12\x11\n\rQUERY_SESSION\x10\x0e\x12\x1a\n\x16QUERY_SESSION_RESPONSE\x10\x0f\"&\n\x04Init\x12\r\n\x05token\x18\x01 \x02(\t\x12\x0f\n\x07version\x18\x02 \x02(\t\"8\n\x0cInitResponse\x12\x17\n\x06status\x18\x01 \x02(\t:\x07success\x12\x0f\n\x07version\x18\x02 \x02(\t\"\xc5\x05\n\nNewSession\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x12\n\nsessionUri\x18\x02 \x02(\t\x12\x15\n\rdependencyUri\x18\x03 \x03(\t\x12I\n\x06header\x18\x04 \x03(\x0b\x32\x39.com.spirent.service.execution.protocol.NewSession.Header\x12\x14\n\x0cparamFileUri\x18\x05 \x03(\t\x12S\n\x0brequirement\x18\x06 \x03(\x0b\x32>.com.spirent.service.execution.protocol.NewSession.Requirement\x12V\n\nproperties\x18\x07 \x01(\x0b\x32\x42.com.spirent.service.execution.protocol.NewSession.PropertiesGroup\x12\x16\n\x0eresponseMapLib\x18\x08 \x01(\t\x1a%\n\x06Header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x1a\xff\x01\n\x0fPropertiesGroup\x12\x0c\n\x04name\x18\x01 \x02(\t\x12_\n\nproperties\x18\x02 \x03(\x0b\x32K.com.spirent.service.execution.protocol.NewSession.PropertiesGroup.Property\x12T\n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x42.com.spirent.service.execution.protocol.NewSession.PropertiesGroup\x1a\'\n\x08Property\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x1a*\n\x0bRequirement\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"\x88\x02\n\x12NewSessionResponse\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x01\x12V\n\nstepResult\x18\x03 \x01(\x0e\x32\x39.com.spirent.service.execution.protocol.SessionStepResult:\x07SUCCESS\x12X\n\x07\x64\x65tails\x18\x04 \x01(\x0b\x32G.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails\x12\x1b\n\rallowTerminal\x18\x05 \x01(\x08:\x04true\"3\n\x10SendTerminalData\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xc3\x01\n\x18SendTerminalDataResponse\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12Y\n\x07\x63\x61pture\x18\x03 \x01(\x0b\x32H.com.spirent.service.execution.protocol.SendTerminalDataResponse.Capture\x1a+\n\x07\x43\x61pture\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\t\"\xce\x02\n\rSessionAction\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x02(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\t\x12\x41\n\nparameters\x18\x04 \x03(\x0b\x32-.com.spirent.service.execution.protocol.Param\x12g\n\x0fresponseMapMode\x18\x05 \x01(\x0e\x32\x45.com.spirent.service.execution.protocol.SessionAction.ResponseModeMap:\x07\x44\x45\x46\x41ULT\x12\x13\n\x0bresponseMap\x18\x06 \x01(\t\"H\n\x0fResponseModeMap\x12\x08\n\x04\x41UTO\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\x08\n\x04\x46ILE\x10\x02\x12\x0b\n\x07LIBRARY\x10\x03\x12\x07\n\x03OFF\x10\x04\"\xee\x01\n\x15SessionActionResponse\x12\x11\n\tsessionId\x18\x01 \x02(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x01\x12V\n\nstepResult\x18\x03 \x01(\x0e\x32\x39.com.spirent.service.execution.protocol.SessionStepResult:\x07SUCCESS\x12X\n\x07\x64\x65tails\x18\x04 \x01(\x0b\x32G.com.spirent.service.execution.protocol.StepMessage.StepResponseDetails\"\x97\x01\n\x11SessionTerminated\x12\x62\n\x06status\x18\x01 \x02(\x0e\x32@.com.spirent.service.execution.protocol.SessionTerminated.Status:\x10\x41GENT_TERMINATED\"\x1e\n\x06Status\x12\x14\n\x10\x41GENT_TERMINATED\x10\x01\"\x0e\n\x0cListProjects\"(\n\x14ListProjectsResponse\x12\x10\n\x08projects\x18\x01 \x03(\t\"\x94\x01\n\x0cQueryProject\x12\x0f\n\x07project\x18\x01 \x02(\t\x12\x1d\n\x0fsessionProfiles\x18\x02 \x01(\x08:\x04true\x12\x18\n\ntopologies\x18\x03 \x01(\x08:\x04true\x12\x1d\n\x0eparameterFiles\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0cresponseMaps\x18\x05 \x01(\x08:\x05\x66\x61lse\"\xed\x02\n\x14QueryProjectResponse\x12\x0f\n\x07project\x18\x01 \x02(\t\x12\x17\n\x0fsessionProfiles\x18\x02 \x03(\t\x12Y\n\ntopologies\x18\x03 \x03(\x0b\x32\x45.com.spirent.service.execution.protocol.QueryProjectResponse.Topology\x12\x16\n\x0eparameterFiles\x18\x04 \x03(\t\x12\x14\n\x0cresponseMaps\x18\x05 \x03(\t\x1a\xa1\x01\n\x08Topology\x12\x0c\n\x04name\x18\x01 \x02(\t\x12]\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32L.com.spirent.service.execution.protocol.QueryProjectResponse.Topology.Device\x1a(\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sessions\x18\x02 \x03(\t\"6\n\x0cQuerySession\x12\x12\n\nsessionUri\x18\x01 \x02(\t\x12\x12\n\nspecificQC\x18\x02 \x01(\t\"\x9b\x02\n\x14QuerySessionResponse\x12Y\n\tquickCall\x18\x02 \x03(\x0b\x32\x46.com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall\x1a\xa7\x01\n\tQuickCall\x12\x0c\n\x04name\x18\x01 \x02(\t\x12]\n\x04\x61rgs\x18\x02 \x03(\x0b\x32O.com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.Argument\x1a-\n\x08\x41rgument\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t*W\n\x0cReportResult\x12\x08\n\x04PASS\x10\x00\x12\x11\n\rINDETERMINATE\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\t\n\x05\x41\x42ORT\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\n\n\x06\x43\x41NCEL\x10\x05*S\n\x11SessionStepResult\x12\x0b\n\x07\x41\x42ORTED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07SKIPPED\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x42\x02H\x01')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_REPORTRESULT = _descriptor.EnumDescriptor(
  name='ReportResult',
  full_name='com.spirent.service.execution.protocol.ReportResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PASS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDETERMINATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCEL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11932,
  serialized_end=12019,
)
_sym_db.RegisterEnumDescriptor(_REPORTRESULT)

ReportResult = enum_type_wrapper.EnumTypeWrapper(_REPORTRESULT)
_SESSIONSTEPRESULT = _descriptor.EnumDescriptor(
  name='SessionStepResult',
  full_name='com.spirent.service.execution.protocol.SessionStepResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12021,
  serialized_end=12104,
)
_sym_db.RegisterEnumDescriptor(_SESSIONSTEPRESULT)

SessionStepResult = enum_type_wrapper.EnumTypeWrapper(_SESSIONSTEPRESULT)
PASS = 0
INDETERMINATE = 1
FAIL = 2
ABORT = 3
ERROR = 4
CANCEL = 5
ABORTED = 0
FAILED = 1
SKIPPED = 2
SUCCESS = 3
TIMEOUT = 4


_EXECUTIONMESSAGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='com.spirent.service.execution.protocol.ExecutionMessage.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CANCEL_MESSAGE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT_MESSAGE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_MESSAGE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVOKE_ACK', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVOKE_MESSAGE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVOKE_RESPONSE', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPORT_MESSAGE', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STEP_MESSAGE', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATE_MESSAGE', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_MESSAGE', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_ISSUE_MESSAGE', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_SESSION_MESSAGE', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_SESSION_RESPONSE', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEND_TERMINAL_DATA_MESSAGE', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEND_TERMINAL_DATA_RESPONSE', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_ACTION_MESSAGE', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_ACTION_RESPONSE', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_PROJECTS', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_PROJECTS_RESPONSE', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_PROJECT', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_PROJECT_RESPONSE', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_SESSION', index=21, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_SESSION_RESPONSE', index=22, number=23,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2077,
  serialized_end=2624,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONMESSAGE_TYPE)

_EXECUTIONISSUEMESSAGE_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.Severity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFORMATION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3090,
  serialized_end=3151,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONISSUEMESSAGE_SEVERITY)

_INVOKEMESSAGE_DETAILLEVEL = _descriptor.EnumDescriptor(
  name='DetailLevel',
  full_name='com.spirent.service.execution.protocol.InvokeMessage.DetailLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPORT_ONLY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ISSUES_ONLY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ISSUES_WITH_STEPS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_ISSUES_ERROR_STEPS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_ISSUES_ALL_STEPS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST_RESPONSE', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4053,
  serialized_end=4208,
)
_sym_db.RegisterEnumDescriptor(_INVOKEMESSAGE_DETAILLEVEL)

_STEPMESSAGE_STEPRESULT = _descriptor.EnumDescriptor(
  name='StepResult',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7094,
  serialized_end=7170,
)
_sym_db.RegisterEnumDescriptor(_STEPMESSAGE_STEPRESULT)

_CLIENTSESSIONCONTROLMESSAGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INIT_MESSAGE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_RESPONSE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_SESSION_MESSAGE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_SESSION_RESPONSE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEND_TERMINAL_DATA_MESSAGE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEND_TERMINAL_DATA_RESPONSE', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_ACTION_MESSAGE', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_ACTION_RESPONSE', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_TERMINATED', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_PROJECTS', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_PROJECTS_RESPONSE', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_PROJECT', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_PROJECT_RESPONSE', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_SESSION', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_SESSION_RESPONSE', index=14, number=15,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8570,
  serialized_end=8951,
)
_sym_db.RegisterEnumDescriptor(_CLIENTSESSIONCONTROLMESSAGE_TYPE)

_SESSIONACTION_RESPONSEMODEMAP = _descriptor.EnumDescriptor(
  name='ResponseModeMap',
  full_name='com.spirent.service.execution.protocol.SessionAction.ResponseModeMap',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIBRARY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10544,
  serialized_end=10616,
)
_sym_db.RegisterEnumDescriptor(_SESSIONACTION_RESPONSEMODEMAP)

_SESSIONTERMINATED_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='com.spirent.service.execution.protocol.SessionTerminated.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AGENT_TERMINATED', index=0, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10981,
  serialized_end=11011,
)
_sym_db.RegisterEnumDescriptor(_SESSIONTERMINATED_STATUS)


_EXECUTIONMESSAGE = _descriptor.Descriptor(
  name='ExecutionMessage',
  full_name='com.spirent.service.execution.protocol.ExecutionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.spirent.service.execution.protocol.ExecutionMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cancelMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.cancelMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heartbeatMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.heartbeatMessage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.initMessage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invokeAck', full_name='com.spirent.service.execution.protocol.ExecutionMessage.invokeAck', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invokeMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.invokeMessage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invokeResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.invokeResponse', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reportMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.reportMessage', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.stepMessage', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminateMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.terminateMessage', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokenMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.tokenMessage', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executionIssueMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.executionIssueMessage', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newSessionMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.newSessionMessage', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newSessionResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.newSessionResponse', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sendTerminalDataMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.sendTerminalDataMessage', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sendTerminalDataResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.sendTerminalDataResponse', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionActionMessage', full_name='com.spirent.service.execution.protocol.ExecutionMessage.sessionActionMessage', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionActionResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.sessionActionResponse', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listProjects', full_name='com.spirent.service.execution.protocol.ExecutionMessage.listProjects', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listProjectsResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.listProjectsResponse', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queryProject', full_name='com.spirent.service.execution.protocol.ExecutionMessage.queryProject', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queryProjectResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.queryProjectResponse', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='querySession', full_name='com.spirent.service.execution.protocol.ExecutionMessage.querySession', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='querySessionResponse', full_name='com.spirent.service.execution.protocol.ExecutionMessage.querySessionResponse', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXECUTIONMESSAGE_TYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=2624,
)


_CANCELMESSAGE = _descriptor.Descriptor(
  name='CancelMessage',
  full_name='com.spirent.service.execution.protocol.CancelMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.CancelMessage.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2626,
  serialized_end=2660,
)


_EXECUTIONISSUEMESSAGE = _descriptor.Descriptor(
  name='ExecutionIssueMessage',
  full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileUri', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.fileUri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='issueIndex', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.issueIndex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.location', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='originator', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.originator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='procedureName', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.procedureName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reportId', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.reportId', index=6,
      number=7, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.sessionId', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='severity', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.severity', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepId', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.stepId', index=9,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testCaseStepId', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.testCaseStepId', index=10,
      number=11, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.line', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startCol', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.startCol', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endCol', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.endCol', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineCount', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.lineCount', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequenceNum', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.sequenceNum', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='issueTime', full_name='com.spirent.service.execution.protocol.ExecutionIssueMessage.issueTime', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXECUTIONISSUEMESSAGE_SEVERITY,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2663,
  serialized_end=3151,
)


_HEARTBEATMESSAGE = _descriptor.Descriptor(
  name='HeartbeatMessage',
  full_name='com.spirent.service.execution.protocol.HeartbeatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memoryUsage', full_name='com.spirent.service.execution.protocol.HeartbeatMessage.memoryUsage', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='processCpuLoad', full_name='com.spirent.service.execution.protocol.HeartbeatMessage.processCpuLoad', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='systemCpuLoad', full_name='com.spirent.service.execution.protocol.HeartbeatMessage.systemCpuLoad', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3153,
  serialized_end=3251,
)


_INVOKEACK = _descriptor.Descriptor(
  name='InvokeAck',
  full_name='com.spirent.service.execution.protocol.InvokeAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.InvokeAck.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='com.spirent.service.execution.protocol.InvokeAck.startTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3253,
  serialized_end=3302,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='com.spirent.service.execution.protocol.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.Param.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.Param.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='com.spirent.service.execution.protocol.Param.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3304,
  serialized_end=3407,
)


_INVOKEMESSAGE_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='com.spirent.service.execution.protocol.InvokeMessage.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.InvokeMessage.Header.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.InvokeMessage.Header.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3943,
  serialized_end=3980,
)

_INVOKEMESSAGE_RESERVATION = _descriptor.Descriptor(
  name='Reservation',
  full_name='com.spirent.service.execution.protocol.InvokeMessage.Reservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservationId', full_name='com.spirent.service.execution.protocol.InvokeMessage.Reservation.reservationId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservationVelocityUrl', full_name='com.spirent.service.execution.protocol.InvokeMessage.Reservation.reservationVelocityUrl', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3982,
  serialized_end=4050,
)

_INVOKEMESSAGE = _descriptor.Descriptor(
  name='InvokeMessage',
  full_name='com.spirent.service.execution.protocol.InvokeMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.spirent.service.execution.protocol.InvokeMessage.token', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='header', full_name='com.spirent.service.execution.protocol.InvokeMessage.header', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reportId', full_name='com.spirent.service.execution.protocol.InvokeMessage.reportId', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dependencyUri', full_name='com.spirent.service.execution.protocol.InvokeMessage.dependencyUri', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paramFileUri', full_name='com.spirent.service.execution.protocol.InvokeMessage.paramFileUri', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='com.spirent.service.execution.protocol.InvokeMessage.parameters', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation', full_name='com.spirent.service.execution.protocol.InvokeMessage.reservation', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testbedUri', full_name='com.spirent.service.execution.protocol.InvokeMessage.testbedUri', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testCaseUri', full_name='com.spirent.service.execution.protocol.InvokeMessage.testCaseUri', index=8,
      number=9, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detailLevel', full_name='com.spirent.service.execution.protocol.InvokeMessage.detailLevel', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_INVOKEMESSAGE_HEADER, _INVOKEMESSAGE_RESERVATION, ],
  enum_types=[
    _INVOKEMESSAGE_DETAILLEVEL,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3410,
  serialized_end=4208,
)


_INITMESSAGE_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='com.spirent.service.execution.protocol.InitMessage.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.InitMessage.Capability.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.InitMessage.Capability.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4476,
  serialized_end=4517,
)

_INITMESSAGE_RESTRICTION = _descriptor.Descriptor(
  name='Restriction',
  full_name='com.spirent.service.execution.protocol.InitMessage.Restriction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.InitMessage.Restriction.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.InitMessage.Restriction.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4519,
  serialized_end=4561,
)

_INITMESSAGE = _descriptor.Descriptor(
  name='InitMessage',
  full_name='com.spirent.service.execution.protocol.InitMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agentId', full_name='com.spirent.service.execution.protocol.InitMessage.agentId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='agentName', full_name='com.spirent.service.execution.protocol.InitMessage.agentName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocolVersion', full_name='com.spirent.service.execution.protocol.InitMessage.protocolVersion', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capability', full_name='com.spirent.service.execution.protocol.InitMessage.capability', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.InitMessage.sessionId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='restriction', full_name='com.spirent.service.execution.protocol.InitMessage.restriction', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_INITMESSAGE_CAPABILITY, _INITMESSAGE_RESTRICTION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4211,
  serialized_end=4561,
)


_INVOKERESPONSE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='com.spirent.service.execution.protocol.InvokeResponse.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='com.spirent.service.execution.protocol.InvokeResponse.Error.code', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.spirent.service.execution.protocol.InvokeResponse.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4790,
  serialized_end=4828,
)

_INVOKERESPONSE = _descriptor.Descriptor(
  name='InvokeResponse',
  full_name='com.spirent.service.execution.protocol.InvokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reportResult', full_name='com.spirent.service.execution.protocol.InvokeResponse.reportResult', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='com.spirent.service.execution.protocol.InvokeResponse.startTime', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='com.spirent.service.execution.protocol.InvokeResponse.endTime', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.InvokeResponse.sessionId', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.spirent.service.execution.protocol.InvokeResponse.error', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_INVOKERESPONSE_ERROR, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4564,
  serialized_end=4828,
)


_TERMINATEMESSAGE = _descriptor.Descriptor(
  name='TerminateMessage',
  full_name='com.spirent.service.execution.protocol.TerminateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cause', full_name='com.spirent.service.execution.protocol.TerminateMessage.cause', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4830,
  serialized_end=4863,
)


_TOKENMESSAGE = _descriptor.Descriptor(
  name='TokenMessage',
  full_name='com.spirent.service.execution.protocol.TokenMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.spirent.service.execution.protocol.TokenMessage.token', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4865,
  serialized_end=4894,
)


_REPORTMESSAGE = _descriptor.Descriptor(
  name='ReportMessage',
  full_name='com.spirent.service.execution.protocol.ReportMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reportId', full_name='com.spirent.service.execution.protocol.ReportMessage.reportId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='com.spirent.service.execution.protocol.ReportMessage.startTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='com.spirent.service.execution.protocol.ReportMessage.endTime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parentStepIndex', full_name='com.spirent.service.execution.protocol.ReportMessage.parentStepIndex', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parentReportId', full_name='com.spirent.service.execution.protocol.ReportMessage.parentReportId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testPath', full_name='com.spirent.service.execution.protocol.ReportMessage.testPath', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testId', full_name='com.spirent.service.execution.protocol.ReportMessage.testId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='com.spirent.service.execution.protocol.ReportMessage.result', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentageComplete', full_name='com.spirent.service.execution.protocol.ReportMessage.percentageComplete', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='com.spirent.service.execution.protocol.ReportMessage.parameters', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4897,
  serialized_end=5214,
)


_STEPMESSAGE_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='com.spirent.service.execution.protocol.StepMessage.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='com.spirent.service.execution.protocol.StepMessage.Action.action', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.spirent.service.execution.protocol.StepMessage.Action.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actions', full_name='com.spirent.service.execution.protocol.StepMessage.Action.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5734,
  serialized_end=5856,
)

_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valuesQuery', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument.valuesQuery', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpretAs', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument.interpretAs', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6478,
  serialized_end=6544,
)

_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS = _descriptor.Descriptor(
  name='Alias',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queryFormat', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.queryFormat', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.arguments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS_ARGUMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6327,
  serialized_end=6544,
)

_STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE = _descriptor.Descriptor(
  name='AnalysisRule',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='extractor', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule.extractor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whenTrue', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule.whenTrue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whenFalse', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule.whenFalse', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actions', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule.actions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6547,
  serialized_end=6715,
)

_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.line', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineCount', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.lineCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startCol', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.startCol', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endCol', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.endCol', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item.items', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6882,
  serialized_end=7092,
)

_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA = _descriptor.Descriptor(
  name='StructuredData',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.map', index=0,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMapUri', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.responseMapUri', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.items', index=2,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6718,
  serialized_end=7092,
)

_STEPMESSAGE_STEPRESPONSEDETAILS = _descriptor.Descriptor(
  name='StepResponseDetails',
  full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isAutoMapped', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.isAutoMapped', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='postProcessing', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.postProcessing', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='analysisRules', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.analysisRules', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='structuredData', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.structuredData', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.aliases', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS, _STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE, _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5859,
  serialized_end=7092,
)

_STEPMESSAGE = _descriptor.Descriptor(
  name='StepMessage',
  full_name='com.spirent.service.execution.protocol.StepMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reportId', full_name='com.spirent.service.execution.protocol.StepMessage.reportId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepId', full_name='com.spirent.service.execution.protocol.StepMessage.stepId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parentStepId', full_name='com.spirent.service.execution.protocol.StepMessage.parentStepId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testCaseStepId', full_name='com.spirent.service.execution.protocol.StepMessage.testCaseStepId', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threadId', full_name='com.spirent.service.execution.protocol.StepMessage.threadId', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.StepMessage.sessionId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionType', full_name='com.spirent.service.execution.protocol.StepMessage.sessionType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='procedure', full_name='com.spirent.service.execution.protocol.StepMessage.procedure', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='com.spirent.service.execution.protocol.StepMessage.action', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='com.spirent.service.execution.protocol.StepMessage.context', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='com.spirent.service.execution.protocol.StepMessage.target', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='com.spirent.service.execution.protocol.StepMessage.command', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startOffset', full_name='com.spirent.service.execution.protocol.StepMessage.startOffset', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.spirent.service.execution.protocol.StepMessage.duration', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emulated', full_name='com.spirent.service.execution.protocol.StepMessage.emulated', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepResult', full_name='com.spirent.service.execution.protocol.StepMessage.stepResult', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='com.spirent.service.execution.protocol.StepMessage.details', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.spirent.service.execution.protocol.StepMessage.properties', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequenceNum', full_name='com.spirent.service.execution.protocol.StepMessage.sequenceNum', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_STEPMESSAGE_ACTION, _STEPMESSAGE_STEPRESPONSEDETAILS, ],
  enum_types=[
    _STEPMESSAGE_STEPRESULT,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5217,
  serialized_end=7170,
)


_CLIENTSESSIONCONTROLMESSAGE = _descriptor.Descriptor(
  name='ClientSessionControlMessage',
  full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initMessage', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.initMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.initResponse', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newSessionMessage', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.newSessionMessage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newSessionResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.newSessionResponse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sendTerminalDataMessage', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.sendTerminalDataMessage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sendTerminalDataResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.sendTerminalDataResponse', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionActionMessage', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.sessionActionMessage', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionActionResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.sessionActionResponse', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionTerminatedMessage', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.sessionTerminatedMessage', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listProjects', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.listProjects', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listProjectsResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.listProjectsResponse', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queryProject', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.queryProject', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queryProjectResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.queryProjectResponse', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='querySession', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.querySession', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='querySessionResponse', full_name='com.spirent.service.execution.protocol.ClientSessionControlMessage.querySessionResponse', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTSESSIONCONTROLMESSAGE_TYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7173,
  serialized_end=8951,
)


_INIT = _descriptor.Descriptor(
  name='Init',
  full_name='com.spirent.service.execution.protocol.Init',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.spirent.service.execution.protocol.Init.token', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='com.spirent.service.execution.protocol.Init.version', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8953,
  serialized_end=8991,
)


_INITRESPONSE = _descriptor.Descriptor(
  name='InitResponse',
  full_name='com.spirent.service.execution.protocol.InitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.spirent.service.execution.protocol.InitResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=_b("success").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='com.spirent.service.execution.protocol.InitResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8993,
  serialized_end=9049,
)


_NEWSESSION_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='com.spirent.service.execution.protocol.NewSession.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.NewSession.Header.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.NewSession.Header.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3943,
  serialized_end=3980,
)

_NEWSESSION_PROPERTIESGROUP_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.Property.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9678,
  serialized_end=9717,
)

_NEWSESSION_PROPERTIESGROUP = _descriptor.Descriptor(
  name='PropertiesGroup',
  full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='children', full_name='com.spirent.service.execution.protocol.NewSession.PropertiesGroup.children', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_NEWSESSION_PROPERTIESGROUP_PROPERTY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9462,
  serialized_end=9717,
)

_NEWSESSION_REQUIREMENT = _descriptor.Descriptor(
  name='Requirement',
  full_name='com.spirent.service.execution.protocol.NewSession.Requirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.NewSession.Requirement.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.spirent.service.execution.protocol.NewSession.Requirement.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9719,
  serialized_end=9761,
)

_NEWSESSION = _descriptor.Descriptor(
  name='NewSession',
  full_name='com.spirent.service.execution.protocol.NewSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.NewSession.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionUri', full_name='com.spirent.service.execution.protocol.NewSession.sessionUri', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dependencyUri', full_name='com.spirent.service.execution.protocol.NewSession.dependencyUri', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='header', full_name='com.spirent.service.execution.protocol.NewSession.header', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paramFileUri', full_name='com.spirent.service.execution.protocol.NewSession.paramFileUri', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requirement', full_name='com.spirent.service.execution.protocol.NewSession.requirement', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.spirent.service.execution.protocol.NewSession.properties', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMapLib', full_name='com.spirent.service.execution.protocol.NewSession.responseMapLib', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_NEWSESSION_HEADER, _NEWSESSION_PROPERTIESGROUP, _NEWSESSION_REQUIREMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9052,
  serialized_end=9761,
)


_NEWSESSIONRESPONSE = _descriptor.Descriptor(
  name='NewSessionResponse',
  full_name='com.spirent.service.execution.protocol.NewSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.NewSessionResponse.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.spirent.service.execution.protocol.NewSessionResponse.duration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepResult', full_name='com.spirent.service.execution.protocol.NewSessionResponse.stepResult', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='com.spirent.service.execution.protocol.NewSessionResponse.details', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allowTerminal', full_name='com.spirent.service.execution.protocol.NewSessionResponse.allowTerminal', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9764,
  serialized_end=10028,
)


_SENDTERMINALDATA = _descriptor.Descriptor(
  name='SendTerminalData',
  full_name='com.spirent.service.execution.protocol.SendTerminalData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.SendTerminalData.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.spirent.service.execution.protocol.SendTerminalData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10030,
  serialized_end=10081,
)


_SENDTERMINALDATARESPONSE_CAPTURE = _descriptor.Descriptor(
  name='Capture',
  full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.Capture',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.Capture.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.Capture.response', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10236,
  serialized_end=10279,
)

_SENDTERMINALDATARESPONSE = _descriptor.Descriptor(
  name='SendTerminalDataResponse',
  full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capture', full_name='com.spirent.service.execution.protocol.SendTerminalDataResponse.capture', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SENDTERMINALDATARESPONSE_CAPTURE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10084,
  serialized_end=10279,
)


_SESSIONACTION = _descriptor.Descriptor(
  name='SessionAction',
  full_name='com.spirent.service.execution.protocol.SessionAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.SessionAction.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='com.spirent.service.execution.protocol.SessionAction.action', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='com.spirent.service.execution.protocol.SessionAction.command', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='com.spirent.service.execution.protocol.SessionAction.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMapMode', full_name='com.spirent.service.execution.protocol.SessionAction.responseMapMode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMap', full_name='com.spirent.service.execution.protocol.SessionAction.responseMap', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SESSIONACTION_RESPONSEMODEMAP,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10282,
  serialized_end=10616,
)


_SESSIONACTIONRESPONSE = _descriptor.Descriptor(
  name='SessionActionResponse',
  full_name='com.spirent.service.execution.protocol.SessionActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='com.spirent.service.execution.protocol.SessionActionResponse.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.spirent.service.execution.protocol.SessionActionResponse.duration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepResult', full_name='com.spirent.service.execution.protocol.SessionActionResponse.stepResult', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='com.spirent.service.execution.protocol.SessionActionResponse.details', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10619,
  serialized_end=10857,
)


_SESSIONTERMINATED = _descriptor.Descriptor(
  name='SessionTerminated',
  full_name='com.spirent.service.execution.protocol.SessionTerminated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.spirent.service.execution.protocol.SessionTerminated.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SESSIONTERMINATED_STATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10860,
  serialized_end=11011,
)


_LISTPROJECTS = _descriptor.Descriptor(
  name='ListProjects',
  full_name='com.spirent.service.execution.protocol.ListProjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11013,
  serialized_end=11027,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='com.spirent.service.execution.protocol.ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='com.spirent.service.execution.protocol.ListProjectsResponse.projects', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11029,
  serialized_end=11069,
)


_QUERYPROJECT = _descriptor.Descriptor(
  name='QueryProject',
  full_name='com.spirent.service.execution.protocol.QueryProject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='com.spirent.service.execution.protocol.QueryProject.project', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionProfiles', full_name='com.spirent.service.execution.protocol.QueryProject.sessionProfiles', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topologies', full_name='com.spirent.service.execution.protocol.QueryProject.topologies', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameterFiles', full_name='com.spirent.service.execution.protocol.QueryProject.parameterFiles', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMaps', full_name='com.spirent.service.execution.protocol.QueryProject.responseMaps', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11072,
  serialized_end=11220,
)


_QUERYPROJECTRESPONSE_TOPOLOGY_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology.Device.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology.Device.sessions', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11548,
  serialized_end=11588,
)

_QUERYPROJECTRESPONSE_TOPOLOGY = _descriptor.Descriptor(
  name='Topology',
  full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='devices', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.Topology.devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_QUERYPROJECTRESPONSE_TOPOLOGY_DEVICE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11427,
  serialized_end=11588,
)

_QUERYPROJECTRESPONSE = _descriptor.Descriptor(
  name='QueryProjectResponse',
  full_name='com.spirent.service.execution.protocol.QueryProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.project', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sessionProfiles', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.sessionProfiles', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topologies', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.topologies', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameterFiles', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.parameterFiles', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseMaps', full_name='com.spirent.service.execution.protocol.QueryProjectResponse.responseMaps', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_QUERYPROJECTRESPONSE_TOPOLOGY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11223,
  serialized_end=11588,
)


_QUERYSESSION = _descriptor.Descriptor(
  name='QuerySession',
  full_name='com.spirent.service.execution.protocol.QuerySession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionUri', full_name='com.spirent.service.execution.protocol.QuerySession.sessionUri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='specificQC', full_name='com.spirent.service.execution.protocol.QuerySession.specificQC', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11590,
  serialized_end=11644,
)


_QUERYSESSIONRESPONSE_QUICKCALL_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.Argument.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.Argument.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11885,
  serialized_end=11930,
)

_QUERYSESSIONRESPONSE_QUICKCALL = _descriptor.Descriptor(
  name='QuickCall',
  full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSESSIONRESPONSE_QUICKCALL_ARGUMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11763,
  serialized_end=11930,
)

_QUERYSESSIONRESPONSE = _descriptor.Descriptor(
  name='QuerySessionResponse',
  full_name='com.spirent.service.execution.protocol.QuerySessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quickCall', full_name='com.spirent.service.execution.protocol.QuerySessionResponse.quickCall', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSESSIONRESPONSE_QUICKCALL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11647,
  serialized_end=11930,
)

_EXECUTIONMESSAGE.fields_by_name['type'].enum_type = _EXECUTIONMESSAGE_TYPE
_EXECUTIONMESSAGE.fields_by_name['cancelMessage'].message_type = _CANCELMESSAGE
_EXECUTIONMESSAGE.fields_by_name['heartbeatMessage'].message_type = _HEARTBEATMESSAGE
_EXECUTIONMESSAGE.fields_by_name['initMessage'].message_type = _INITMESSAGE
_EXECUTIONMESSAGE.fields_by_name['invokeAck'].message_type = _INVOKEACK
_EXECUTIONMESSAGE.fields_by_name['invokeMessage'].message_type = _INVOKEMESSAGE
_EXECUTIONMESSAGE.fields_by_name['invokeResponse'].message_type = _INVOKERESPONSE
_EXECUTIONMESSAGE.fields_by_name['reportMessage'].message_type = _REPORTMESSAGE
_EXECUTIONMESSAGE.fields_by_name['stepMessage'].message_type = _STEPMESSAGE
_EXECUTIONMESSAGE.fields_by_name['terminateMessage'].message_type = _TERMINATEMESSAGE
_EXECUTIONMESSAGE.fields_by_name['tokenMessage'].message_type = _TOKENMESSAGE
_EXECUTIONMESSAGE.fields_by_name['executionIssueMessage'].message_type = _EXECUTIONISSUEMESSAGE
_EXECUTIONMESSAGE.fields_by_name['newSessionMessage'].message_type = _NEWSESSION
_EXECUTIONMESSAGE.fields_by_name['newSessionResponse'].message_type = _NEWSESSIONRESPONSE
_EXECUTIONMESSAGE.fields_by_name['sendTerminalDataMessage'].message_type = _SENDTERMINALDATA
_EXECUTIONMESSAGE.fields_by_name['sendTerminalDataResponse'].message_type = _SENDTERMINALDATARESPONSE
_EXECUTIONMESSAGE.fields_by_name['sessionActionMessage'].message_type = _SESSIONACTION
_EXECUTIONMESSAGE.fields_by_name['sessionActionResponse'].message_type = _SESSIONACTIONRESPONSE
_EXECUTIONMESSAGE.fields_by_name['listProjects'].message_type = _LISTPROJECTS
_EXECUTIONMESSAGE.fields_by_name['listProjectsResponse'].message_type = _LISTPROJECTSRESPONSE
_EXECUTIONMESSAGE.fields_by_name['queryProject'].message_type = _QUERYPROJECT
_EXECUTIONMESSAGE.fields_by_name['queryProjectResponse'].message_type = _QUERYPROJECTRESPONSE
_EXECUTIONMESSAGE.fields_by_name['querySession'].message_type = _QUERYSESSION
_EXECUTIONMESSAGE.fields_by_name['querySessionResponse'].message_type = _QUERYSESSIONRESPONSE
_EXECUTIONMESSAGE_TYPE.containing_type = _EXECUTIONMESSAGE
_EXECUTIONISSUEMESSAGE.fields_by_name['severity'].enum_type = _EXECUTIONISSUEMESSAGE_SEVERITY
_EXECUTIONISSUEMESSAGE_SEVERITY.containing_type = _EXECUTIONISSUEMESSAGE
_PARAM.fields_by_name['parameters'].message_type = _PARAM
_INVOKEMESSAGE_HEADER.containing_type = _INVOKEMESSAGE
_INVOKEMESSAGE_RESERVATION.containing_type = _INVOKEMESSAGE
_INVOKEMESSAGE.fields_by_name['token'].message_type = _TOKENMESSAGE
_INVOKEMESSAGE.fields_by_name['header'].message_type = _INVOKEMESSAGE_HEADER
_INVOKEMESSAGE.fields_by_name['parameters'].message_type = _PARAM
_INVOKEMESSAGE.fields_by_name['reservation'].message_type = _INVOKEMESSAGE_RESERVATION
_INVOKEMESSAGE.fields_by_name['detailLevel'].enum_type = _INVOKEMESSAGE_DETAILLEVEL
_INVOKEMESSAGE_DETAILLEVEL.containing_type = _INVOKEMESSAGE
_INITMESSAGE_CAPABILITY.containing_type = _INITMESSAGE
_INITMESSAGE_RESTRICTION.containing_type = _INITMESSAGE
_INITMESSAGE.fields_by_name['capability'].message_type = _INITMESSAGE_CAPABILITY
_INITMESSAGE.fields_by_name['restriction'].message_type = _INITMESSAGE_RESTRICTION
_INVOKERESPONSE_ERROR.containing_type = _INVOKERESPONSE
_INVOKERESPONSE.fields_by_name['reportResult'].enum_type = _REPORTRESULT
_INVOKERESPONSE.fields_by_name['error'].message_type = _INVOKERESPONSE_ERROR
_REPORTMESSAGE.fields_by_name['result'].enum_type = _REPORTRESULT
_REPORTMESSAGE.fields_by_name['parameters'].message_type = _PARAM
_STEPMESSAGE_ACTION.fields_by_name['actions'].message_type = _STEPMESSAGE_ACTION
_STEPMESSAGE_ACTION.containing_type = _STEPMESSAGE
_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS_ARGUMENT.containing_type = _STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS
_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS.fields_by_name['arguments'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS_ARGUMENT
_STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS.containing_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE.fields_by_name['actions'].message_type = _STEPMESSAGE_ACTION
_STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE.containing_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM.fields_by_name['items'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM
_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM.containing_type = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA
_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA.fields_by_name['items'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM
_STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA.containing_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_STEPMESSAGE_STEPRESPONSEDETAILS.fields_by_name['postProcessing'].message_type = _STEPMESSAGE_ACTION
_STEPMESSAGE_STEPRESPONSEDETAILS.fields_by_name['analysisRules'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE
_STEPMESSAGE_STEPRESPONSEDETAILS.fields_by_name['structuredData'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA
_STEPMESSAGE_STEPRESPONSEDETAILS.fields_by_name['aliases'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS
_STEPMESSAGE_STEPRESPONSEDETAILS.containing_type = _STEPMESSAGE
_STEPMESSAGE.fields_by_name['stepResult'].enum_type = _STEPMESSAGE_STEPRESULT
_STEPMESSAGE.fields_by_name['details'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_STEPMESSAGE_STEPRESULT.containing_type = _STEPMESSAGE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['type'].enum_type = _CLIENTSESSIONCONTROLMESSAGE_TYPE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['initMessage'].message_type = _INIT
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['initResponse'].message_type = _INITRESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['newSessionMessage'].message_type = _NEWSESSION
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['newSessionResponse'].message_type = _NEWSESSIONRESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['sendTerminalDataMessage'].message_type = _SENDTERMINALDATA
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['sendTerminalDataResponse'].message_type = _SENDTERMINALDATARESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['sessionActionMessage'].message_type = _SESSIONACTION
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['sessionActionResponse'].message_type = _SESSIONACTIONRESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['sessionTerminatedMessage'].message_type = _SESSIONTERMINATED
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['listProjects'].message_type = _LISTPROJECTS
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['listProjectsResponse'].message_type = _LISTPROJECTSRESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['queryProject'].message_type = _QUERYPROJECT
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['queryProjectResponse'].message_type = _QUERYPROJECTRESPONSE
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['querySession'].message_type = _QUERYSESSION
_CLIENTSESSIONCONTROLMESSAGE.fields_by_name['querySessionResponse'].message_type = _QUERYSESSIONRESPONSE
_CLIENTSESSIONCONTROLMESSAGE_TYPE.containing_type = _CLIENTSESSIONCONTROLMESSAGE
_NEWSESSION_HEADER.containing_type = _NEWSESSION
_NEWSESSION_PROPERTIESGROUP_PROPERTY.containing_type = _NEWSESSION_PROPERTIESGROUP
_NEWSESSION_PROPERTIESGROUP.fields_by_name['properties'].message_type = _NEWSESSION_PROPERTIESGROUP_PROPERTY
_NEWSESSION_PROPERTIESGROUP.fields_by_name['children'].message_type = _NEWSESSION_PROPERTIESGROUP
_NEWSESSION_PROPERTIESGROUP.containing_type = _NEWSESSION
_NEWSESSION_REQUIREMENT.containing_type = _NEWSESSION
_NEWSESSION.fields_by_name['header'].message_type = _NEWSESSION_HEADER
_NEWSESSION.fields_by_name['requirement'].message_type = _NEWSESSION_REQUIREMENT
_NEWSESSION.fields_by_name['properties'].message_type = _NEWSESSION_PROPERTIESGROUP
_NEWSESSIONRESPONSE.fields_by_name['stepResult'].enum_type = _SESSIONSTEPRESULT
_NEWSESSIONRESPONSE.fields_by_name['details'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_SENDTERMINALDATARESPONSE_CAPTURE.containing_type = _SENDTERMINALDATARESPONSE
_SENDTERMINALDATARESPONSE.fields_by_name['capture'].message_type = _SENDTERMINALDATARESPONSE_CAPTURE
_SESSIONACTION.fields_by_name['parameters'].message_type = _PARAM
_SESSIONACTION.fields_by_name['responseMapMode'].enum_type = _SESSIONACTION_RESPONSEMODEMAP
_SESSIONACTION_RESPONSEMODEMAP.containing_type = _SESSIONACTION
_SESSIONACTIONRESPONSE.fields_by_name['stepResult'].enum_type = _SESSIONSTEPRESULT
_SESSIONACTIONRESPONSE.fields_by_name['details'].message_type = _STEPMESSAGE_STEPRESPONSEDETAILS
_SESSIONTERMINATED.fields_by_name['status'].enum_type = _SESSIONTERMINATED_STATUS
_SESSIONTERMINATED_STATUS.containing_type = _SESSIONTERMINATED
_QUERYPROJECTRESPONSE_TOPOLOGY_DEVICE.containing_type = _QUERYPROJECTRESPONSE_TOPOLOGY
_QUERYPROJECTRESPONSE_TOPOLOGY.fields_by_name['devices'].message_type = _QUERYPROJECTRESPONSE_TOPOLOGY_DEVICE
_QUERYPROJECTRESPONSE_TOPOLOGY.containing_type = _QUERYPROJECTRESPONSE
_QUERYPROJECTRESPONSE.fields_by_name['topologies'].message_type = _QUERYPROJECTRESPONSE_TOPOLOGY
_QUERYSESSIONRESPONSE_QUICKCALL_ARGUMENT.containing_type = _QUERYSESSIONRESPONSE_QUICKCALL
_QUERYSESSIONRESPONSE_QUICKCALL.fields_by_name['args'].message_type = _QUERYSESSIONRESPONSE_QUICKCALL_ARGUMENT
_QUERYSESSIONRESPONSE_QUICKCALL.containing_type = _QUERYSESSIONRESPONSE
_QUERYSESSIONRESPONSE.fields_by_name['quickCall'].message_type = _QUERYSESSIONRESPONSE_QUICKCALL
DESCRIPTOR.message_types_by_name['ExecutionMessage'] = _EXECUTIONMESSAGE
DESCRIPTOR.message_types_by_name['CancelMessage'] = _CANCELMESSAGE
DESCRIPTOR.message_types_by_name['ExecutionIssueMessage'] = _EXECUTIONISSUEMESSAGE
DESCRIPTOR.message_types_by_name['HeartbeatMessage'] = _HEARTBEATMESSAGE
DESCRIPTOR.message_types_by_name['InvokeAck'] = _INVOKEACK
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['InvokeMessage'] = _INVOKEMESSAGE
DESCRIPTOR.message_types_by_name['InitMessage'] = _INITMESSAGE
DESCRIPTOR.message_types_by_name['InvokeResponse'] = _INVOKERESPONSE
DESCRIPTOR.message_types_by_name['TerminateMessage'] = _TERMINATEMESSAGE
DESCRIPTOR.message_types_by_name['TokenMessage'] = _TOKENMESSAGE
DESCRIPTOR.message_types_by_name['ReportMessage'] = _REPORTMESSAGE
DESCRIPTOR.message_types_by_name['StepMessage'] = _STEPMESSAGE
DESCRIPTOR.message_types_by_name['ClientSessionControlMessage'] = _CLIENTSESSIONCONTROLMESSAGE
DESCRIPTOR.message_types_by_name['Init'] = _INIT
DESCRIPTOR.message_types_by_name['InitResponse'] = _INITRESPONSE
DESCRIPTOR.message_types_by_name['NewSession'] = _NEWSESSION
DESCRIPTOR.message_types_by_name['NewSessionResponse'] = _NEWSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['SendTerminalData'] = _SENDTERMINALDATA
DESCRIPTOR.message_types_by_name['SendTerminalDataResponse'] = _SENDTERMINALDATARESPONSE
DESCRIPTOR.message_types_by_name['SessionAction'] = _SESSIONACTION
DESCRIPTOR.message_types_by_name['SessionActionResponse'] = _SESSIONACTIONRESPONSE
DESCRIPTOR.message_types_by_name['SessionTerminated'] = _SESSIONTERMINATED
DESCRIPTOR.message_types_by_name['ListProjects'] = _LISTPROJECTS
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryProject'] = _QUERYPROJECT
DESCRIPTOR.message_types_by_name['QueryProjectResponse'] = _QUERYPROJECTRESPONSE
DESCRIPTOR.message_types_by_name['QuerySession'] = _QUERYSESSION
DESCRIPTOR.message_types_by_name['QuerySessionResponse'] = _QUERYSESSIONRESPONSE
DESCRIPTOR.enum_types_by_name['ReportResult'] = _REPORTRESULT
DESCRIPTOR.enum_types_by_name['SessionStepResult'] = _SESSIONSTEPRESULT

ExecutionMessage = _reflection.GeneratedProtocolMessageType('ExecutionMessage', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ExecutionMessage)
  ))
_sym_db.RegisterMessage(ExecutionMessage)

CancelMessage = _reflection.GeneratedProtocolMessageType('CancelMessage', (_message.Message,), dict(
  DESCRIPTOR = _CANCELMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.CancelMessage)
  ))
_sym_db.RegisterMessage(CancelMessage)

ExecutionIssueMessage = _reflection.GeneratedProtocolMessageType('ExecutionIssueMessage', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONISSUEMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ExecutionIssueMessage)
  ))
_sym_db.RegisterMessage(ExecutionIssueMessage)

HeartbeatMessage = _reflection.GeneratedProtocolMessageType('HeartbeatMessage', (_message.Message,), dict(
  DESCRIPTOR = _HEARTBEATMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.HeartbeatMessage)
  ))
_sym_db.RegisterMessage(HeartbeatMessage)

InvokeAck = _reflection.GeneratedProtocolMessageType('InvokeAck', (_message.Message,), dict(
  DESCRIPTOR = _INVOKEACK,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeAck)
  ))
_sym_db.RegisterMessage(InvokeAck)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), dict(
  DESCRIPTOR = _PARAM,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.Param)
  ))
_sym_db.RegisterMessage(Param)

InvokeMessage = _reflection.GeneratedProtocolMessageType('InvokeMessage', (_message.Message,), dict(

  Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR = _INVOKEMESSAGE_HEADER,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeMessage.Header)
    ))
  ,

  Reservation = _reflection.GeneratedProtocolMessageType('Reservation', (_message.Message,), dict(
    DESCRIPTOR = _INVOKEMESSAGE_RESERVATION,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeMessage.Reservation)
    ))
  ,
  DESCRIPTOR = _INVOKEMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeMessage)
  ))
_sym_db.RegisterMessage(InvokeMessage)
_sym_db.RegisterMessage(InvokeMessage.Header)
_sym_db.RegisterMessage(InvokeMessage.Reservation)

InitMessage = _reflection.GeneratedProtocolMessageType('InitMessage', (_message.Message,), dict(

  Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), dict(
    DESCRIPTOR = _INITMESSAGE_CAPABILITY,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InitMessage.Capability)
    ))
  ,

  Restriction = _reflection.GeneratedProtocolMessageType('Restriction', (_message.Message,), dict(
    DESCRIPTOR = _INITMESSAGE_RESTRICTION,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InitMessage.Restriction)
    ))
  ,
  DESCRIPTOR = _INITMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InitMessage)
  ))
_sym_db.RegisterMessage(InitMessage)
_sym_db.RegisterMessage(InitMessage.Capability)
_sym_db.RegisterMessage(InitMessage.Restriction)

InvokeResponse = _reflection.GeneratedProtocolMessageType('InvokeResponse', (_message.Message,), dict(

  Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
    DESCRIPTOR = _INVOKERESPONSE_ERROR,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeResponse.Error)
    ))
  ,
  DESCRIPTOR = _INVOKERESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InvokeResponse)
  ))
_sym_db.RegisterMessage(InvokeResponse)
_sym_db.RegisterMessage(InvokeResponse.Error)

TerminateMessage = _reflection.GeneratedProtocolMessageType('TerminateMessage', (_message.Message,), dict(
  DESCRIPTOR = _TERMINATEMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.TerminateMessage)
  ))
_sym_db.RegisterMessage(TerminateMessage)

TokenMessage = _reflection.GeneratedProtocolMessageType('TokenMessage', (_message.Message,), dict(
  DESCRIPTOR = _TOKENMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.TokenMessage)
  ))
_sym_db.RegisterMessage(TokenMessage)

ReportMessage = _reflection.GeneratedProtocolMessageType('ReportMessage', (_message.Message,), dict(
  DESCRIPTOR = _REPORTMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ReportMessage)
  ))
_sym_db.RegisterMessage(ReportMessage)

StepMessage = _reflection.GeneratedProtocolMessageType('StepMessage', (_message.Message,), dict(

  Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
    DESCRIPTOR = _STEPMESSAGE_ACTION,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.Action)
    ))
  ,

  StepResponseDetails = _reflection.GeneratedProtocolMessageType('StepResponseDetails', (_message.Message,), dict(

    Alias = _reflection.GeneratedProtocolMessageType('Alias', (_message.Message,), dict(

      Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), dict(
        DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS_ARGUMENT,
        __module__ = 'ExecutionProtocol_pb2'
        # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias.Argument)
        ))
      ,
      DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS_ALIAS,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.Alias)
      ))
    ,

    AnalysisRule = _reflection.GeneratedProtocolMessageType('AnalysisRule', (_message.Message,), dict(
      DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS_ANALYSISRULE,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.AnalysisRule)
      ))
    ,

    StructuredData = _reflection.GeneratedProtocolMessageType('StructuredData', (_message.Message,), dict(

      Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
        DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA_ITEM,
        __module__ = 'ExecutionProtocol_pb2'
        # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData.Item)
        ))
      ,
      DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS_STRUCTUREDDATA,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails.StructuredData)
      ))
    ,
    DESCRIPTOR = _STEPMESSAGE_STEPRESPONSEDETAILS,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage.StepResponseDetails)
    ))
  ,
  DESCRIPTOR = _STEPMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.StepMessage)
  ))
_sym_db.RegisterMessage(StepMessage)
_sym_db.RegisterMessage(StepMessage.Action)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails.Alias)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails.Alias.Argument)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails.AnalysisRule)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails.StructuredData)
_sym_db.RegisterMessage(StepMessage.StepResponseDetails.StructuredData.Item)

ClientSessionControlMessage = _reflection.GeneratedProtocolMessageType('ClientSessionControlMessage', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSESSIONCONTROLMESSAGE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ClientSessionControlMessage)
  ))
_sym_db.RegisterMessage(ClientSessionControlMessage)

Init = _reflection.GeneratedProtocolMessageType('Init', (_message.Message,), dict(
  DESCRIPTOR = _INIT,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.Init)
  ))
_sym_db.RegisterMessage(Init)

InitResponse = _reflection.GeneratedProtocolMessageType('InitResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.InitResponse)
  ))
_sym_db.RegisterMessage(InitResponse)

NewSession = _reflection.GeneratedProtocolMessageType('NewSession', (_message.Message,), dict(

  Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR = _NEWSESSION_HEADER,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSession.Header)
    ))
  ,

  PropertiesGroup = _reflection.GeneratedProtocolMessageType('PropertiesGroup', (_message.Message,), dict(

    Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(
      DESCRIPTOR = _NEWSESSION_PROPERTIESGROUP_PROPERTY,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSession.PropertiesGroup.Property)
      ))
    ,
    DESCRIPTOR = _NEWSESSION_PROPERTIESGROUP,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSession.PropertiesGroup)
    ))
  ,

  Requirement = _reflection.GeneratedProtocolMessageType('Requirement', (_message.Message,), dict(
    DESCRIPTOR = _NEWSESSION_REQUIREMENT,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSession.Requirement)
    ))
  ,
  DESCRIPTOR = _NEWSESSION,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSession)
  ))
_sym_db.RegisterMessage(NewSession)
_sym_db.RegisterMessage(NewSession.Header)
_sym_db.RegisterMessage(NewSession.PropertiesGroup)
_sym_db.RegisterMessage(NewSession.PropertiesGroup.Property)
_sym_db.RegisterMessage(NewSession.Requirement)

NewSessionResponse = _reflection.GeneratedProtocolMessageType('NewSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _NEWSESSIONRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.NewSessionResponse)
  ))
_sym_db.RegisterMessage(NewSessionResponse)

SendTerminalData = _reflection.GeneratedProtocolMessageType('SendTerminalData', (_message.Message,), dict(
  DESCRIPTOR = _SENDTERMINALDATA,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SendTerminalData)
  ))
_sym_db.RegisterMessage(SendTerminalData)

SendTerminalDataResponse = _reflection.GeneratedProtocolMessageType('SendTerminalDataResponse', (_message.Message,), dict(

  Capture = _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), dict(
    DESCRIPTOR = _SENDTERMINALDATARESPONSE_CAPTURE,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SendTerminalDataResponse.Capture)
    ))
  ,
  DESCRIPTOR = _SENDTERMINALDATARESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SendTerminalDataResponse)
  ))
_sym_db.RegisterMessage(SendTerminalDataResponse)
_sym_db.RegisterMessage(SendTerminalDataResponse.Capture)

SessionAction = _reflection.GeneratedProtocolMessageType('SessionAction', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONACTION,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SessionAction)
  ))
_sym_db.RegisterMessage(SessionAction)

SessionActionResponse = _reflection.GeneratedProtocolMessageType('SessionActionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONACTIONRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SessionActionResponse)
  ))
_sym_db.RegisterMessage(SessionActionResponse)

SessionTerminated = _reflection.GeneratedProtocolMessageType('SessionTerminated', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONTERMINATED,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.SessionTerminated)
  ))
_sym_db.RegisterMessage(SessionTerminated)

ListProjects = _reflection.GeneratedProtocolMessageType('ListProjects', (_message.Message,), dict(
  DESCRIPTOR = _LISTPROJECTS,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ListProjects)
  ))
_sym_db.RegisterMessage(ListProjects)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPROJECTSRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.ListProjectsResponse)
  ))
_sym_db.RegisterMessage(ListProjectsResponse)

QueryProject = _reflection.GeneratedProtocolMessageType('QueryProject', (_message.Message,), dict(
  DESCRIPTOR = _QUERYPROJECT,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QueryProject)
  ))
_sym_db.RegisterMessage(QueryProject)

QueryProjectResponse = _reflection.GeneratedProtocolMessageType('QueryProjectResponse', (_message.Message,), dict(

  Topology = _reflection.GeneratedProtocolMessageType('Topology', (_message.Message,), dict(

    Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
      DESCRIPTOR = _QUERYPROJECTRESPONSE_TOPOLOGY_DEVICE,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QueryProjectResponse.Topology.Device)
      ))
    ,
    DESCRIPTOR = _QUERYPROJECTRESPONSE_TOPOLOGY,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QueryProjectResponse.Topology)
    ))
  ,
  DESCRIPTOR = _QUERYPROJECTRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QueryProjectResponse)
  ))
_sym_db.RegisterMessage(QueryProjectResponse)
_sym_db.RegisterMessage(QueryProjectResponse.Topology)
_sym_db.RegisterMessage(QueryProjectResponse.Topology.Device)

QuerySession = _reflection.GeneratedProtocolMessageType('QuerySession', (_message.Message,), dict(
  DESCRIPTOR = _QUERYSESSION,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QuerySession)
  ))
_sym_db.RegisterMessage(QuerySession)

QuerySessionResponse = _reflection.GeneratedProtocolMessageType('QuerySessionResponse', (_message.Message,), dict(

  QuickCall = _reflection.GeneratedProtocolMessageType('QuickCall', (_message.Message,), dict(

    Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), dict(
      DESCRIPTOR = _QUERYSESSIONRESPONSE_QUICKCALL_ARGUMENT,
      __module__ = 'ExecutionProtocol_pb2'
      # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall.Argument)
      ))
    ,
    DESCRIPTOR = _QUERYSESSIONRESPONSE_QUICKCALL,
    __module__ = 'ExecutionProtocol_pb2'
    # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QuerySessionResponse.QuickCall)
    ))
  ,
  DESCRIPTOR = _QUERYSESSIONRESPONSE,
  __module__ = 'ExecutionProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.spirent.service.execution.protocol.QuerySessionResponse)
  ))
_sym_db.RegisterMessage(QuerySessionResponse)
_sym_db.RegisterMessage(QuerySessionResponse.QuickCall)
_sym_db.RegisterMessage(QuerySessionResponse.QuickCall.Argument)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001'))
# @@protoc_insertion_point(module_scope)
